package com.info666.app.infraredRemote.activity;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Build;
import android.os.Bundle;
import android.webkit.JavascriptInterface;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import com.info666.app.infraredRemote.R;
import com.info666.app.infraredRemote.api.ConsumerIrManagerApi;
import com.king.zxing.CameraScan;
import com.tencent.bugly.crashreport.CrashReport;
import com.tencent.vasdolly.helper.ChannelReaderUtil;

import java.lang.reflect.Method;

import cn.hutool.core.convert.Convert;

public class InfraredRemoteActivity extends AppCompatActivity {
    private WebView webView;

    private SharedPreferences sp;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_infrared_remote);
        sp = getSharedPreferences("config", Context.MODE_PRIVATE);
        this.initView();
        this.initData();
    }

    private void initView(){
        this.webView = findViewById(R.id.wb_infrared_remote);
        // 设置WebChromeClient
        this.webView.setWebChromeClient(new WebChromeClient() {
            @Override
            public void onProgressChanged(WebView webView, int progress) {
                // 增加Javascript异常监控
                CrashReport.setJavascriptMonitor(webView, true);
                super.onProgressChanged(webView, progress);
            }
        });
    }

    private void initData(){
        WebSettings webSettings = webView.getSettings();
        webSettings.setDomStorageEnabled(true);
        //  允许WebView加载JavaScript
        webSettings.setJavaScriptEnabled(true);
        // 允许跨域
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN){
            webView.getSettings().setAllowUniversalAccessFromFileURLs(true);
        }else{
            try {
                Class<?> clazz = webView.getSettings().getClass();
                Method method = clazz.getMethod("setAllowUniversalAccessFromFileURLs", boolean.class);
                if (method != null) {
                    method.invoke(webView.getSettings(), true);
                }
            } catch (Exception e){
                e.printStackTrace();
            }
        }
        webView.setWebViewClient(new WebViewClient());
        webView.addJavascriptInterface(new ConsumerIrManagerApi(getApplicationContext()), "adIrApi");
        webView.addJavascriptInterface(new JavaScriptInterface(getApplicationContext()), "adApi");
        webView.loadUrl(sp.getString("url","https://www.qq.com"));
        webView.setWebContentsDebuggingEnabled(true);
    }


    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (Activity.RESULT_OK == resultCode) {
            String msg = data.getStringExtra(CameraScan.SCAN_RESULT);
            webView.evaluateJavascript(String.format("javascript:_scanCodeCallback(0,'%s');",Convert.strToUnicode(msg)),(str)->{});
        }
    }

    public class JavaScriptInterface{
        private Context context;

        public JavaScriptInterface(Context context){
            this.context = context;
        }

        @JavascriptInterface
        public void startQrCapture(){
            Intent intent = new Intent(this.context, MyCaptureActivity.class);
            startActivityForResult(intent,Activity.RESULT_FIRST_USER);
        }

        @JavascriptInterface
        public String getChannel(){
            return ChannelReaderUtil.getChannel(this.context.getApplicationContext());
        }

    }

}
