package com.info666.app.infraredRemote.api;

import android.content.Context;
import android.os.Build;
import android.os.Handler;
import android.os.HandlerThread;
import android.util.Log;
import android.webkit.JavascriptInterface;

import com.alibaba.fastjson2.JSON;
import com.tencent.bugly.crashreport.BuglyLog;
import com.tencent.bugly.crashreport.CrashReport;

import cn.hutool.core.exceptions.ExceptionUtil;

public class ConsumerIrManagerApi {

    private ConsumerIrManagerApi instance;
    private android.hardware.ConsumerIrManager service;
    private Handler mHandler ;

    public ConsumerIrManagerApi(Context context) {
        //Android4.4才开始支持红外功能
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            // 获取系统的红外遥控服务
            service = (android.hardware.ConsumerIrManager) context.getApplicationContext().getSystemService(Context.CONSUMER_IR_SERVICE);
        }
        HandlerThread handlerThread = new HandlerThread("consumerIrThread");//创建一个handlerThread线程
        handlerThread.start();//启动该线程
        mHandler =  new Handler(handlerThread.getLooper());
    }

    public ConsumerIrManagerApi getConsumerIrManager(Context context) {
        if (instance == null) {
            instance = new ConsumerIrManagerApi(context);
        }
        return instance;
    }

    /**
     * 手机是否有红外功能
     *
     * @return
     */
    @JavascriptInterface
    public boolean hasIrEmitter() {
        boolean has = this.checkHasIrEmitter();
        if(!has){
            CrashReport.postCatchedException(new RuntimeException("不支持红外"));
        }
        return has;
    }

    public boolean checkHasIrEmitter(){
        //android4.4及以上版本&有红外功能
        if (service != null && Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            BuglyLog.d("ConsumerIrManagerApi", "hasIrEmitter("+service.hasIrEmitter()+")");
            return service.hasIrEmitter();
        }
        BuglyLog.e("ConsumerIrManagerApi", "hasIrEmitter(false)");
        //android4.4以下及4.4以上没红外功能
        return false;
    }


    /**
     * 发射红外信号
     *
     * @param carrierFrequency  信号频率，单位赫兹(Hz)，家用电器的红外频率通常使用38000Hz；
     * @param pattern 整型数组形式的信号格式。
     */
    @JavascriptInterface
    public void transmit(int carrierFrequency, int[] pattern) {
        if (service != null && Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            //异步发射
            mHandler.post(() -> {
                try {
                    BuglyLog.d("ConsumerIrManagerApi", "transmit(" + carrierFrequency + "," + JSON.toJSONString(pattern) + ")");
                    service.transmit(carrierFrequency, pattern);
                } catch (Exception e) {
                    BuglyLog.e("--红外发射失败--", ExceptionUtil.getSimpleMessage(e));
                    CrashReport.postCatchedException(e);
                    throw e;
                }
            });
        }
    }

    /**
     * 获取可支持的红外信号频率
     *
     * @return
     */
    @JavascriptInterface
    public String getCarrierFrequencies() {
        Log.d("ConsumerIrManagerApi","getCarrierFrequencies()");
        if (service != null && Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            return JSON.toJSONString(service.getCarrierFrequencies());
        }
        return null;
    }
}